.. _examples_sec:

Examples
========

You can find examples of using the ``empix`` library in the notebook located at
``<root>/examples/basic_usage.ipynb``, where ``<root>`` is the root of the
``empix`` repository. You can find the repository `here
<https://github.com/mrfitzpa/empix>`_.
